## v0.4.5 (2025-12-11)

### Fix

- **cicd**: remove unnecessary steps
- **keyvault**: pipeline access to keyvault
- add groups and primitive

## v0.4.4 (2025-11-24)

### Fix

- remove persistence of credentials at cicd-tools

## v0.4.3 (2025-11-24)

### Fix

- check if auth is correct
- remove credentials cicd

## v0.4.2 (2025-11-24)

### Fix

- remove twine dependency
- remove twine upload
- pipeline

## v0.4.1 (2025-11-24)

### Fix

- new release
- definitive pipeline

## v0.4.1a0 (2025-11-24)

### Fix

- error on pypeline
- upadte pipeline
- publishing to feed

## v0.4.0 (2025-11-24)

### Feat

- config service agnostic from environment

### Refactor

- amend pipeline to publish to feed

## v0.3.1 (2025-11-03)

### Fix

- ammend update of cz version

## v0.3.0 (2025-11-03)

## v0.2.1 (2025-10-30)

### Feat

- load group of vars

### Fix

- try other approach to set pypi-token
- see pypi token

## v0.2.0 (2025-10-30)

### Feat

- first relase is raised

### Fix

- correct bumping
